@@ -1,7 +1,7 @@
 
 #' @title Initialization: netsim Module
 #'
-#' @description This function initializes the master \code{dat} object on which
+#' @description This function initializes the main \code{dat} object on which
 #'              data are stored, simulates the initial state of the network, and
 #'              simulates disease status and other attributes.
 #'
@@ -11,6 +11,8 @@
 #' @param control An \code{EpiModel} object of class \code{\link{control.net}}.
 #' @param s Simulation number, used for restarting dependent simulations.
 #'
+#' @return A \code{dat} main list object.
+#'
 #' @export
 #' @keywords internal
 #'
@@ -18,12 +20,11 @@ initialize.net <- function(x, param, init, control, s) {
 
   if (control$start == 1) {
 
-    # Master Data List --------------------------------------------------------
+    # Main Data List --------------------------------------------------------
     dat <- create_dat_object(param, init, control)
 
     dat$nwparam <- list()
-    dat$nwparam[[1]] <- x[-which(names(x) == "fit")]
-
+    dat$nwparam[[1]] <- x[!(names(x) %in% c("fit", "newnetwork"))]
 
     # Initial Network Simulation ----------------------------------------------
 
@@ -93,23 +94,22 @@ initialize.net <- function(x, param, init, control, s) {
 #' @description This function sets the initial disease status on the
 #'              network given the specified initial conditions.
 #'
-#' @param dat Master list object containing a \code{networkDynamic} object and
-#'        other initialization information passed from \code{\link{netsim}}.
+#' @inheritParams recovery.net
 #'
 #' @details
 #' This internal function sets, either randomly or deterministically, the nodes
-#' that are infected at the starting time of network simulations, \eqn{t_1}.
-#' If the number to be initially infected is passed, this function may set the
-#' initial number infected based on the number specified, either as a a set of
-#' random draws from a binomial distribution or as the exact number specified.
-#' In either case, the specific nodes infected are a random sample from the
-#' network. In contrast, a set of specific nodes may be infected by passing the
-#' vector to \code{\link{netsim}}.
+#' that are infected at \eqn{t_1}, the starting time of network simulations. If
+#' the number to be initially infected is passed, this function sets the initial
+#' number infected based on the number specified, either as a set of random
+#' draws from a binomial distribution or as the exact number specified. In
+#' either case, the specific nodes infected are a random sample from the
+#' network. In contrast, a set of specific nodes may be infected by passing a
+#' vector containing the status of each node to \code{\link{netsim}}.
 #'
-#' This module sets the time of infection for those nodes set infected
-#' at the starting time of network simulations, \eqn{t_1}. For vital
-#' dynamics models, the infection time for those nodes is a random draw from an
-#' exponential distribution with the rate parameter defined by the
+#' For the initially infected nodes, this module sets the time of infection as
+#' \eqn{t_1}, the starting time of network simulations. For models with vital
+#' dynamics, the infection time for those initially infected nodes is a random
+#' draw from an exponential distribution with the rate parameter defined by the
 #' \code{di.rate} argument. For models without vital dynamics, the infection
 #' time is a random draw from a uniform distribution of integers with a minimum
 #' of 1 and a maximum of the number of time steps in the model. In both cases,
@@ -117,6 +117,8 @@ initialize.net <- function(x, param, init, control, s) {
 #' -1, and 2 is added to allow for possible infection times up until step 2,
 #' when the disease simulation time loop starts.
 #'
+#' @inherit recovery.net return
+#'
 #' @seealso This is an initialization module for \code{\link{netsim}}.
 #'
 #' @export
@@ -138,7 +140,6 @@ init_status.net <- function(dat) {
   if (vital == TRUE) {
     di.rate <- get_param(dat, "di.rate")
   }
-  isTERGM <- get_control(dat, "isTERGM")
 
   # Variables ---------------------------------------------------------------
   i.num <- get_init(dat, "i.num", override.null.error = TRUE)
@@ -200,16 +201,11 @@ init_status.net <- function(dat) {
     if (statOnNw == FALSE) {
       dat$nw[[1]] <- set_vertex_attribute(dat$nw[[1]], "status", status)
     }
-    if (isTERGM == TRUE) {
-      dat$nw[[1]] <- activate.vertex.attribute(dat$nw[[1]],
-                                               prefix = "testatus",
-                                               value = status,
-                                               onset = 1,
-                                               terminus = Inf)
-    } else {
-      dat$temp$nw_list[[1]] <- set_vertex_attribute(dat$temp$nw_list[[1]],
-                                                    "status", status)
-    }
+    dat$nw[[1]] <- activate.vertex.attribute(dat$nw[[1]],
+                                             prefix = "testatus",
+                                             value = status,
+                                             onset = 1,
+                                             terminus = Inf)
   }
 
 
