@@ -6,10 +6,12 @@
 #'              panels for ERGMs, for use in \code{\link{netsim}} modeling.
 #'
 #' @param x An \code{EpiModel} object of class \code{\link{netest}}.
-#' @param dat A master object passed through \code{\link{netsim}}.
+#' @inheritParams recovery.net
 #' @param nsteps For TERGMs, the number of time steps to simulate the network
 #'        over; for ERGMs, the number of independent network panels to simulate.
 #'
+#' @inherit recovery.net return
+#'
 #' @export
 #' @keywords netUtils internal
 #'
@@ -28,82 +30,73 @@ sim_nets_t1 <- function(x, dat, nsteps) {
 
   save.nwstats <- get_control(dat, "save.nwstats")
 
+  set.control.ergm <- get_control(dat, "set.control.ergm")
+  set.control.tergm <- get_control(dat, "set.control.tergm")
+  set.control.stergm <- get_control(dat, "set.control.stergm")
+
+  # Simulate t0 basis network
+  if (x$edapprox == TRUE) {
+    nw <- simulate(x$formula,
+                   coef = x$coef.form.crude,
+                   basis = x$newnetwork,
+                   constraints = x$constraints,
+                   control = set.control.ergm,
+                   dynamic = FALSE)
+  } else {
+    nw <- x$newnetwork
+  }
+
   # if TERGM, then use tergm package simulation for dynamic network
   if (isTERGM == TRUE) {
-
-    set.control.ergm <- get_control(dat, "set.control.ergm")
-
-    # Simulate t0 basis network
-    if (x$edapprox == TRUE) {
-      nw <- simulate(x$formation,
-                     coef = coef(x$fit),
-                     basis = x$fit$newnetwork,
-                     constraints = x$constraints,
-                     control = set.control.ergm,
-                     dynamic = FALSE)
-    } else {
-      nw <- x$fit$network
-    }
-
-    set.control.stergm <- get_control(dat, "set.control.stergm")
-
-    # Simulate dynamic network
-    suppressWarnings({
+    if (!is.null(set.control.stergm)) {
+      # Simulate dynamic network
       sim <- simulate(nw,
                       formation = x$formation,
                       dissolution = x$coef.diss$dissolution,
                       coef.form = x$coef.form,
                       coef.diss = x$coef.diss$coef.crude,
                       time.slices = nsteps,
-                      time.start = 1,
-                      time.offset = 0,
+                      time.start = 0,
+                      time.offset = 1,
                       constraints = x$constraints,
                       monitor = nwstats.formula,
                       nsim = 1,
                       control = set.control.stergm)
-      sim <- networkDynamic::activate.vertices(sim, onset = 1, terminus = Inf)
-    })
-    dat$nw[[1]] <- sim
-
-  # If ERGM, then use ergm package simulation for x-sectional network panels
-  } else {
-
-    set.control.ergm <- get_control(dat, "set.control.ergm")
-
-    sim <- simulate(x$formation,
-                    coef = coef(x$fit),
-                    basis = x$fit$newnetwork,
-                    constraints = x$constraints,
-                    control = set.control.ergm,
-                    dynamic = FALSE,
-                    monitor = nwstats.formula,
-                    nsim = nsteps)
-
-    # save working network and temp network list
-    if (nsteps == 1) {
-      dat$nw[[1]] <- sim
-      dat$temp$nw_list <- list(sim)
     } else {
-      dat$nw[[1]] <- sim[[1]]
-      dat$temp$nw_list <- sim
+      # Simulate dynamic network
+      sim <- simulate(nw ~ Form(x$formation) +
+                           Persist(x$coef.diss$dissolution),
+                      coef = c(x$coef.form, x$coef.diss$coef.crude),
+                      time.slices = nsteps,
+                      time.start = 0,
+                      time.offset = 1,
+                      constraints = x$constraints,
+                      monitor = nwstats.formula,
+                      nsim = 1,
+                      control = set.control.tergm,
+                      dynamic = TRUE)
     }
+  } else {
+    sim <- simulate(x$formation,
+                    basis = nw,
+                    coef = x$coef.form.crude,
+                    time.slices = nsteps,
+                    time.start = 0,
+                    time.offset = 1,
+                    constraints = x$constraints,
+                    monitor = nwstats.formula,
+                    nsim = 1,
+                    control = set.control.tergm,
+                    dynamic = TRUE)
   }
 
+  dat$nw[[1]] <- networkDynamic::activate.vertices(sim, onset = 0,
+                                                   terminus = Inf)
+
   # Set up nwstats df
   if (save.nwstats == TRUE) {
-    if (isTERGM == FALSE & nsteps > 1) {
-      nwstats <- as.data.frame(
-        simulate(x$formation,
-                 coef = coef(x$fit),
-                 basis = x$fit$newnetwork,
-                 constraints = x$constraints,
-                 control = set.control.ergm,
-                 dynamic = FALSE,
-                 monitor = nwstats.formula,
-                 nsim = nsteps, output = "stats"))
-    } else {
-      nwstats <- attributes(dat$nw[[1]])$stats
-    }
+    nwstats <- attributes(dat$nw[[1]])$stats
+
     keep.cols <- which(!duplicated(colnames(nwstats)))
     nwstats <- nwstats[, keep.cols, drop = FALSE]
     dat$stats$nwstats[[1]] <- nwstats
@@ -120,8 +113,9 @@ sim_nets_t1 <- function(x, dat, nsteps) {
 #'              between the epidemic and demographic processes and the network
 #'              structure.
 #'
-#' @param x A master object passed through \code{\link{netsim}}.
-#' @param at Current time step.
+#' @inheritParams recovery.net
+#'
+#' @inherit recovery.net return
 #'
 #' @export
 #' @keywords netUtils internal
@@ -135,7 +129,7 @@ resim_nets <- function(dat, at) {
   resimulate.network <- get_control(dat, "resimulate.network")
   nwstats.formula <- get_control(dat, "nwstats.formula")
   set.control.stergm <- get_control(dat, "set.control.stergm")
-  set.control.ergm <- get_control(dat, "set.control.ergm")
+  set.control.tergm <- get_control(dat, "set.control.tergm")
   tergmLite.track.duration <- get_control(dat, "tergmLite.track.duration")
 
   # Edges Correction
@@ -160,34 +154,50 @@ resim_nets <- function(dat, at) {
   nwparam <- get_nwparam(dat)
 
   # Network resimulation
-  if (anyActive == TRUE & resimulate.network == TRUE) {
+  if (anyActive == TRUE && resimulate.network == TRUE) {
 
     # Full tergm/network Method
     if (tergmLite == FALSE) {
 
       # TERGM simulation
       if (isTERGM == TRUE) {
-        suppressWarnings(
+        if (!is.null(set.control.stergm)) {
           dat$nw[[1]] <- simulate(dat$nw[[1]],
                                   formation = nwparam$formation,
                                   dissolution = nwparam$coef.diss$dissolution,
                                   coef.form = nwparam$coef.form,
                                   coef.diss = nwparam$coef.diss$coef.adj,
                                   constraints = nwparam$constraints,
-                                  time.start = at,
+                                  time.start = at - 1,
                                   time.slices = 1,
-                                  time.offset = 0,
+                                  time.offset = 1,
                                   monitor = nwstats.formula,
-                                  control = set.control.stergm))
+                                  control = set.control.stergm)
+        } else {
+          dat$nw[[1]] <- simulate(dat$nw[[1]] ~
+                                    Form(nwparam$formation) +
+                                    Persist(nwparam$coef.diss$dissolution),
+                                  coef = c(nwparam$coef.form,
+                                           nwparam$coef.diss$coef.adj),
+                                  constraints = nwparam$constraints,
+                                  time.start = at - 1,
+                                  time.slices = 1,
+                                  time.offset = 1,
+                                  monitor = nwstats.formula,
+                                  control = set.control.tergm,
+                                  dynamic = TRUE)
+        }
       } else {
-        dat$nw[[1]] <- simulate(object = nwparam$formation,
+        dat$nw[[1]] <- simulate(nwparam$formation,
                                 basis = dat$nw[[1]],
-                                coef = nwparam$coef.form,
+                                coef = c(nwparam$coef.form),
                                 constraints = nwparam$constraints,
-                                control = set.control.ergm,
-                                dynamic = FALSE,
+                                time.start = at - 1,
+                                time.slices = 1,
+                                time.offset = 1,
                                 monitor = nwstats.formula,
-                                nsim = 1)
+                                control = set.control.tergm,
+                                dynamic = TRUE)
       }
 
       # Update nwstats data frame
@@ -208,35 +218,56 @@ resim_nets <- function(dat, at) {
       }
 
       if (isTERGM == TRUE) {
-        dat$nw[[1]] <- simulate(nwL,
-                                formation = nwparam$formation,
-                                dissolution = nwparam$coef.diss$dissolution,
-                                coef.form = nwparam$coef.form,
-                                coef.diss = nwparam$coef.diss$coef.adj,
-                                constraints = nwparam$constraints,
-                                time.start = at - 1,
-                                time.slices = 1,
-                                time.offset = 1, # default value
-                                control = set.control.stergm,
-                                output = "final")
+        if (!is.null(set.control.stergm)) {
+          dat$nw[[1]] <- simulate(nwL,
+                                  formation = nwparam$formation,
+                                  dissolution = nwparam$coef.diss$dissolution,
+                                  coef.form = nwparam$coef.form,
+                                  coef.diss = nwparam$coef.diss$coef.adj,
+                                  constraints = nwparam$constraints,
+                                  time.start = at - 1,
+                                  time.slices = 1,
+                                  time.offset = 1, # default value
+                                  control = set.control.stergm,
+                                  output = "final")
+        } else {
+          dat$nw[[1]] <- simulate(nwL ~
+                                    Form(nwparam$formation) +
+                                    Persist(nwparam$coef.diss$dissolution),
+                                  coef = c(nwparam$coef.form,
+                                           nwparam$coef.diss$coef.adj),
+                                  constraints = nwparam$constraints,
+                                  time.start = at - 1,
+                                  time.slices = 1,
+                                  time.offset = 1, # default value
+                                  control = set.control.tergm,
+                                  output = "final",
+                                  dynamic = TRUE)
+        }
       } else {
         dat$nw[[1]] <- simulate(object = nwparam$formation,
                                 basis = nwL,
                                 coef = nwparam$coef.form,
                                 constraints = nwparam$constraints,
-                                control = set.control.ergm,
-                                dynamic = FALSE,
-                                nsim = 1,
-                                output = "network")
+                                time.start = at - 1,
+                                time.slices = 1,
+                                time.offset = 1, # default value
+                                control = set.control.tergm,
+                                output = "final",
+                                dynamic = TRUE)
       }
 
       dat$el[[1]] <- as.edgelist(dat$nw[[1]])
 
       if (save.nwstats == TRUE) {
         term.options <- if (isTERGM == TRUE) {
-          set.control.stergm$term.options
+          if (!is.null(set.control.stergm)) {
+            set.control.stergm$term.options
+          } else {
+            set.control.tergm$term.options
+          }
         } else {
-          set.control.ergm$term.options
+          set.control.tergm$term.options
         }
         nwstats <- summary(dat$control$nwstats.formulas[[1]],
                            basis = dat$nw[[1]],
@@ -259,8 +290,9 @@ resim_nets <- function(dat, at) {
 #'              simulated in \code{\link{netsim}} to preserve the mean
 #'              degree of nodes in the network.
 #'
-#' @param dat Master object in \code{netsim} simulations.
-#' @param at Current time step.
+#' @inheritParams recovery.net
+#'
+#' @inherit recovery.net return
 #'
 #' @keywords internal
 #' @export
